<?php

/**
 * WC_YottaPay_Common class.
 *
 * @since 1.2.0
 */
class WC_YottaPay_Common
{
    static $logger;
    const WC_LOG_FILENAME = 'yottapay-payment-gateway';

    /**
     * Settings link.
     */
    public static function add_action_links($actions)
    {
        $new_links = array(
            '<a href="' . admin_url('admin.php?page=wc-settings&tab=checkout&section=yottapay') . '">Settings</a>',
        );

        $actions = array_merge($actions, $new_links);

        return $actions;
    }

    /**
     * Guideline and API docs links.
     */
    public static function custom_plugin_row_meta($links, $file)
    {
        if (strpos($file, 'yottapay-payment-gateway.php') !== false) {
            $new_links = array(
                '<a href="https://www.yottapay.co.uk/faq-questions/how-to-add-online-checkout-woo" target="_blank">Guideline</a>',
                '<a href="https://doc.yottapay.co.uk/" target="_blank">API docs</a>'
            );

            $links = array_merge($links, $new_links);
        }

        return $links;
    }

    /**
     * WooCommerce fallback notice.
     */
    public static function payment_missing_wc_notice()
    {
        echo '<div class="error"><p><strong>' . sprintf(esc_html__('Yotta Pay requires WooCommerce to be installed and active. You can download %s here.', 'yottapay-payment-gateway'), '<a href="https://woocommerce.com/" target="_blank">WooCommerce</a>') . '</strong></p></div>';
    }

    /**
     * WooCommerce not supported fallback notice.
     */
    public static function payment_wc_not_supported()
    {
        echo '<div class="error"><p><strong>' . sprintf(esc_html__('Yotta Pay requires WooCommerce %1$s or greater to be installed and active. WooCommerce %2$s is no longer supported.', 'yottapay-payment-gateway'), '3.9', WC_VERSION) . '</strong></p></div>';
    }

    /**
     * Check Yotta Pay Gateway sandbox parameter and return Yotta Pay API url.
     */
    public static function get_yottapay_api_url($settings_sandbox)
    {
        if (wc_string_to_bool($settings_sandbox)) {
            return 'https://sandbox.yottapay.co.uk';
        } else {
            return 'https://prod.yottapay.co.uk';
        }
    }

    /**
     * Validate response status.
     */
    public static function validate_response_status($response, $request_body)
    {
        //Check response status
        if (is_wp_error($response)) {
            $error_message = $response->get_error_message();
            throw new Exception($error_message);
        }

        if (wp_remote_retrieve_response_code($response) !== 200) {
            self::get_logger()->info('request_body: ' . print_r($request_body, TRUE), ['source' => self::WC_LOG_FILENAME]);
            throw new Exception('Request error: response code ' . wp_remote_retrieve_response_code($response));
        }

        //Get parameters from response
        $response_body = wp_remote_retrieve_body($response);
        $response_data = json_decode($response_body, true);

        return $response_data;
    }

    /**
     * Get data from Yotta Pay API callback request and return decoded json.
     */
    public static function get_request_data()
    {
        $body = file_get_contents('php://input');

        if (!$body) {
            throw new Exception('get_request_data(): no request data.');
        }

        $request_data = json_decode($body, true);

        return $request_data;
    }

    /**
     * Get data from Yotta Pay API callback request and return decoded json.
     */
    public static function get_logger()
    {
        if (empty(self::$logger)) {
            self::$logger = wc_get_logger();
        }

        return self::$logger;
    }
}


/**
 * YottaPayException class.
 *
 * @extends Exception
 */
class YottaPayException extends Exception
{
}
