<?php
/**
 * Plugin Name: Yotta Pay Payment Gateway
 * Plugin URI: https://yottapay.co.uk/online-checkout
 * Description: Yotta Pay is the fastest and most secure way to accept payments via UK bank account.
 * Version: 1.2.0
 * Author: Yotta Pay
 * Author URI: https://yottapay.co.uk/
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 * Requires PHP: 7.0
 * Requires at least: 5.3
 * Tested up to: 6.1
 * WC requires at least: 3.9
 * WC tested up to: 6.0
 * Text Domain: yottapay-payment-gateway
 */

if (!defined('ABSPATH')) {
    exit;
}

define('YOTTAPAY_TEMPLATE_PATH', plugin_dir_path(__FILE__) . '/templates');

add_action('init', 'yottapay_add_myaccount_refund_endpoint', 1);
add_action('plugins_loaded', 'yottapay_payment_init');
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'yottapay_add_action_links');
add_filter('plugin_row_meta', 'yottapay_custom_plugin_row_meta', 10, 2);
add_filter('woocommerce_payment_gateways', 'add_to_woo_yottapay_payment_gateway');
add_filter('woocommerce_my_account_my_orders_actions', 'yottapay_add_refund_btn_in_actions', 10, 2);
add_filter('woocommerce_order_details_after_order_table', 'yottapay_add_refund_btn_in_order', 10, 1);
add_filter('woocommerce_order_actions', 'yottapay_disable_admin_refund_button', 10, 2);

function yottapay_payment_init()
{
    if (!class_exists('WooCommerce')) {
        add_action('admin_notices', 'yottapay_payment_missing_wc_notice');
        return;
    }

    if (version_compare(WC_VERSION, '3.9', '<')) {
        add_action('admin_notices', 'yottapay_payment_wc_not_supported');
        return;
    }

    require_once plugin_dir_path(__FILE__) . '/includes/class-wc-gateway-yottapay.php';
    require_once plugin_dir_path(__FILE__) . '/includes/class-wc-yottapay-common.php';
    require_once plugin_dir_path(__FILE__) . '/includes/class-wc-yottapay-payment.php';
    require_once plugin_dir_path(__FILE__) . '/includes/class-wc-yottapay-refund.php';
}

function add_to_woo_yottapay_payment_gateway($gateways)
{
    $gateways[] = 'WC_Gateway_YottaPay';
    return $gateways;
}

/**
 * Settings link.
 *
 * @since 1.1.0
 */
function yottapay_add_action_links($actions)
{
    return WC_YottaPay_Common::add_action_links($actions);
}

/**
 * Guideline and API docs links.
 *
 * @since 1.1.0
 */
function yottapay_custom_plugin_row_meta($links, $file)
{
    return WC_YottaPay_Common::custom_plugin_row_meta($links, $file);
}

/**
 * WooCommerce fallback notice.
 *
 * @since 1.0.1
 */
function yottapay_payment_missing_wc_notice()
{
    WC_YottaPay_Common::payment_missing_wc_notice();
}

/**
 * WooCommerce not supported fallback notice.
 *
 * @since 1.0.1
 */
function yottapay_payment_wc_not_supported()
{
    WC_YottaPay_Common::payment_wc_not_supported();
}


/**
 * Yotta Pay refund form endpoint.
 *
 * @since 1.2.0
 */
function yottapay_add_myaccount_refund_endpoint($value = '')
{
    WC_YottaPay_Refund::add_myaccount_refund_endpoint($value);
}

/**
 * Yotta Pay refund button.
 *
 * @since 1.2.0
 */
function yottapay_add_refund_btn_in_actions($actions, $order)
{
    return WC_YottaPay_Refund::add_refund_btn_to_actions($actions, $order);
}

/**
 * Yotta Pay refund button.
 *
 * @since 1.2.0
 */
function yottapay_add_refund_btn_in_order($order)
{
    return WC_YottaPay_Refund::add_refund_btn_to_order($order);
}

/**
 * Disable admin refund button.
 *
 * @since 1.2.0
 */
function yottapay_disable_admin_refund_button($actions, $order)
{
    return WC_YottaPay_Refund::disable_admin_refund_button($actions, $order);
}
